@@ -4,15 +4,14 @@ import sys
 from contextlib import contextmanager
 from enum import Enum
 from functools import reduce
-from typing import Optional
+from typing import Annotated, Optional
 from urllib.parse import urljoin, urlparse
 
 import colorama  # type: ignore
 import requests
 from decouple import config  # type: ignore
 from packaging import version
-from pydantic import BaseModel, confloat, conint, constr
-
+from pydantic import BaseModel, ConstrainedStr, Field
 from qcware.forge import __version__ as Qcware_client_version
 from qcware.forge.config.api_semver import api_semver
 
@@ -50,7 +49,7 @@ def qcware_api_key(override: Optional[str] = None) -> str:
     result = (
         override
         if override is not None
-        else current_context().credentials.qcware_api_key
+        else current_context().credentials.qcware_api_key  # type:ignore
     )
     if result is None:
         raise ConfigurationError(
@@ -396,26 +395,30 @@ def set_ibmq_credentials(
     _set_if("QCWARE_CRED_IBMQ_PROJECT", project)
 
 
-def set_ibmq_credentials_from_ibmq(ibmq):
-    """Set the IBMQ credentials from the ibmq object.
+def set_ibmq_credentials_from_ibmq_provider(
+    provider: "qiskit.providers.ibmq.accountprovider.AccountProvider",
+):
+    """Set the IBMQ credentials from an ibmq provider object.
 
-    Called normally as set_ibmq_credentials_from_ibmq(IBMQ)
+    Called normally as set_ibmq_credentials_from_ibmq(IBMQ.providers()[0]).
+    The IBMQ "factory" can provide several providers, particularly if your
+    IBMQ token is associated with various hubs, groups, or projects.
 
     """
     set_ibmq_credentials(
-        ibmq._credentials.token,
-        ibmq._credentials.hub,
-        ibmq._credentials.group,
-        ibmq._credentials.project,
+        provider.credentials.token,
+        provider.credentials.hub,
+        provider.credentials.group,
+        provider.credentials.project,
     )
 
 
 class IBMQCredentials(BaseModel):
 
-    token: Optional[constr(max_length=255)]
-    hub: Optional[constr(max_length=255)]
-    group: Optional[constr(max_length=255)]
-    project: Optional[constr(max_length=255)]
+    token: Optional[Annotated[str, Field(max_length=255)]]
+    hub: Optional[Annotated[str, Field(max_length=255)]]
+    group: Optional[Annotated[str, Field(max_length=255)]]
+    project: Optional[Annotated[str, Field(max_length=255)]]
 
     @classmethod
     def from_ibmq(cls, ibmq):
@@ -438,7 +441,7 @@ class IBMQCredentials(BaseModel):
 
 
 class ApiCredentials(BaseModel):
-    qcware_api_key: Optional[constr(max_length=255)] = None
+    qcware_api_key: Optional[Annotated[str, Field(max_length=255)]] = None
     ibmq: Optional[IBMQCredentials] = None
 
     class Config:
@@ -465,11 +468,11 @@ class Environment(BaseModel):
     This is set via the environment variable QCWARE_ENVIRONMENT_SOURCE_FILE.
     """
 
-    client: constr(max_length=255)
-    client_version: constr(max_length=255)
-    python_version: constr(max_length=255)
-    environment: constr(max_length=255)
-    source_file: constr(max_length=255)
+    client: Annotated[str, Field(max_length=255)]
+    client_version: Annotated[str, Field(max_length=255)]
+    python_version: Annotated[str, Field(max_length=255)]
+    environment: Annotated[str, Field(max_length=255)]
+    source_file: Annotated[str, Field(max_length=255)]
 
 
 def set_environment_environment(new_environment: str):
@@ -491,12 +494,12 @@ class ApiCallContext(BaseModel):
     override only one field (or a subset).
     """
 
-    qcware_host: Optional[constr(max_length=255)] = None
+    qcware_host: Optional[Annotated[str, Field(max_length=255)]] = None
     credentials: Optional[ApiCredentials] = None
     environment: Optional[Environment] = None
-    server_timeout: Optional[conint(ge=0)] = None
-    client_timeout: Optional[conint(ge=0)] = None
-    async_interval_between_tries: Optional[confloat(ge=0)] = None
+    server_timeout: Optional[Annotated[int, Field(ge=0)]] = None
+    client_timeout: Optional[Annotated[int, Field(ge=0)]] = None
+    async_interval_between_tries: Optional[Annotated[float, Field(ge=0)]] = None
     scheduling_mode: Optional[SchedulingMode] = None
 
     class Config:
@@ -538,7 +541,9 @@ def root_context() -> ApiCallContext:
     )
 
 
-_contexts: contextvars.ContextVar = contextvars.ContextVar("contexts", default=[])
+_contexts: contextvars.ContextVar[ApiCallContext] = contextvars.ContextVar(
+    "contexts", default=[]
+)  # type:ignore
 
 
 def push_context(**kwargs):
@@ -600,7 +605,9 @@ def current_context() -> ApiCallContext:
     through the stack.  Normally not called by the user.
 
     """
-    return reduce(merge_models, _contexts.get(), root_context())
+    # known problem below with mypy and reduce, see https://github.com/python/mypy/issues/4150
+    # among others
+    return reduce(merge_models, _contexts.get(), root_context())  # type:ignore
 
 
 @contextmanager
