@@ -6,36 +6,40 @@ This file should primarily contain the marshaling for argument
 transformations and functions, not so much the transformation functions
 themselves for particular types (those go in the helpers file).
 """
-from ..serialize_quasar import (
+from functools import wraps
+from typing import Any, Callable, Mapping, Optional
+
+from qcware.serialization.serialize_quasar import (
+    list_to_pauli,
+    pauli_to_list,
     quasar_to_string,
     string_to_quasar,
-    pauli_to_list,
-    list_to_pauli,
 )
-from .helpers import (
-    ndarray_to_dict,
+from qcware.serialization.transforms.helpers import (
+    complex_or_real_dtype_to_string,
     dict_to_ndarray,
-    scalar_to_dict,
-    dict_to_scalar,
-    numeric_to_dict,
     dict_to_numeric,
+    dict_to_scalar,
+    ndarray_to_dict,
+    numeric_to_dict,
     remap_q_indices_from_strings,
     remap_q_indices_to_strings,
-    complex_or_real_dtype_to_string,
+    scalar_to_dict,
     string_to_complex_or_real_dtype,
-    to_wire,
-    polynomial_objective_from_wire,
-    constraints_from_wire,
+)
+from qcware.serialization.transforms.to_wire import (
     binary_problem_from_wire,
     binary_results_from_wire,
+    constraints_from_wire,
+    fit_data_from_wire,
+    fit_data_to_wire,
+    polynomial_objective_from_wire,
+    to_wire,
 )
-from typing import Optional, Mapping, Callable
-from ...types.optimization import BinaryProblem
+from qcware.types.optimization import BinaryProblem
 
 
-def update_with_replacers(
-    d: Mapping[object, object], replacers: Mapping[object, Callable]
-):
+def update_with_replacers(d: dict[str, Any], replacers: Mapping[str, Callable]):
     """for all (k,f) in replacers, updates the dict entry marked by k by calling the
     function f on the value"""
     result = d.copy()
@@ -45,7 +49,7 @@ def update_with_replacers(
     return result
 
 
-_to_wire_arg_replacers = {}
+_to_wire_arg_replacers: dict[str, dict[str, Callable]] = {}
 
 
 def client_args_to_wire(method_name: str, **kwargs):
@@ -61,7 +65,26 @@ def client_args_to_wire(method_name: str, **kwargs):
         )
 
 
-_from_wire_arg_replacers = {}
+_from_wire_arg_replacers: dict[str, dict[str, Callable]] = {}
+
+
+def replace_server_args_from_wire(method_name: str):
+    """Decorates a function with a method name for serialization.
+
+    Uses this to transform the keyword parameters (all parameters
+    must be keyword parameters) and call the original function
+    with the transformed parameters.
+    """
+
+    def decorator(func):
+        @wraps(func)
+        def wrapper(*args, **kwargs):
+            kwargs = server_args_from_wire(method_name, **kwargs)
+            return func(*args, **kwargs)
+
+        return wrapper
+
+    return decorator
 
 
 def server_args_from_wire(method_name: str, **kwargs):
@@ -129,7 +152,6 @@ register_argument_transform(
     },
 )
 
-
 register_argument_transform(
     "optimization.brute_force_minimize",
     to_wire={
@@ -152,6 +174,18 @@ register_argument_transform(
     from_wire={"X": dict_to_ndarray, "y": dict_to_ndarray, "T": dict_to_ndarray},
 )
 
+register_argument_transform(
+    "qml.fit",
+    to_wire={"X": ndarray_to_dict, "y": ndarray_to_dict},
+    from_wire={"X": dict_to_ndarray, "y": dict_to_ndarray},
+)
+
+register_argument_transform(
+    "qml.predict",
+    to_wire={"X": ndarray_to_dict, "fit_data": fit_data_to_wire},
+    from_wire={"X": dict_to_ndarray, "fit_data": fit_data_from_wire},
+)
+
 register_argument_transform(
     "qutils.qdot",
     to_wire={
@@ -167,7 +201,7 @@ register_argument_transform(
 )
 
 register_argument_transform(
-    "qutils.distance_estimation",
+    "qutils.qdist",
     to_wire={
         "x": numeric_to_dict,
         "y": numeric_to_dict,
