@@ -1,7 +1,8 @@
 import os
-from typing import Callable, Optional
+from typing import Callable, Optional, cast
 
 import numpy
+from decouple import config
 
 from ..serialize_quasar import (
     dict_to_probability_histogram,
@@ -12,22 +13,26 @@ from ..serialize_quasar import (
     sequence_to_quasar,
 )
 from .helpers import (
-    binary_results_from_wire,
-    brute_optimize_result_from_wire,
     dict_to_ndarray,
     dict_to_numeric,
     dict_to_scalar,
     ndarray_to_dict,
     numeric_to_dict,
     scalar_to_dict,
+)
+from .to_wire import (
+    binary_results_from_wire,
+    brute_optimize_result_from_wire,
+    fit_data_from_wire,
+    fit_data_to_wire,
     to_wire,
 )
 
-_to_wire_result_replacers = {}
+_to_wire_result_replacers: dict[str, Callable] = {}
 
 
 def debug_is_set() -> bool:
-    return os.environ.get("QCWARE_CLIENT_DEBUG", False)
+    return config("QCWARE_CLIENT_DEBUG", default=False, cast=bool)
 
 
 def result_represents_error(worker_result: object):
@@ -50,18 +55,18 @@ def strip_traceback_if_debug_set(error_result: dict) -> dict:
 
 def server_result_to_wire(method_name: str, worker_result: object):
     if result_represents_error(worker_result):
-        return strip_traceback_if_debug_set(worker_result)
+        return strip_traceback_if_debug_set(cast(dict, worker_result))
     else:
         f = _to_wire_result_replacers.get(method_name, lambda x: x)
         return f(worker_result)
 
 
-_from_wire_result_replacers = {}
+_from_wire_result_replacers: dict[str, Callable] = {}
 
 
 def client_result_from_wire(method_name: str, worker_result: object):
     if result_represents_error(worker_result):
-        return strip_traceback_if_debug_set(worker_result)
+        return strip_traceback_if_debug_set(cast(dict, worker_result))
     else:
         f = _from_wire_result_replacers.get(method_name, lambda x: x)
         return f(worker_result)
@@ -96,7 +101,7 @@ register_result_transform(
 )
 
 register_result_transform(
-    "qutils.distance_estimation", to_wire=numeric_to_dict, from_wire=dict_to_numeric
+    "qutils.qdist", to_wire=numeric_to_dict, from_wire=dict_to_numeric
 )
 
 register_result_transform(
@@ -116,6 +121,14 @@ register_result_transform(
     "qml.fit_and_predict", to_wire=ndarray_to_dict, from_wire=dict_to_ndarray
 )
 
+register_result_transform(
+    "qml.fit", to_wire=fit_data_to_wire, from_wire=fit_data_from_wire
+)
+
+register_result_transform(
+    "qml.predict", to_wire=ndarray_to_dict, from_wire=dict_to_ndarray
+)
+
 
 def run_backend_method_to_wire(backend_method_result: dict):
     result = server_result_to_wire(
