@@ -1,6 +1,6 @@
 from .predicate import Predicate
 from .variable_types import Domain
 from .problem_spec import PolynomialObjective, Constraints
-from .results import BruteOptimizeResult
-from .qcware_binary_results import BinaryProblem, BinaryResults
+from .problem_spec import BinaryProblem
+from .results import BruteOptimizeResult, BinaryResults, Sample
 from . import utils
